@@ -5,6 +5,7 @@ import logging
 import traceback
 import math
 import asyncio
+import io
 from importlib.metadata import version
 
 from accqsure.auth import Auth
@@ -13,6 +14,7 @@ from accqsure.document_types import DocumentTypes
 from accqsure.documents import Documents
 from accqsure.manifests import Manifests
 from accqsure.inspections import Inspections
+from accqsure.plots import Plots
 
 from accqsure.exceptions import (
     ApiError,
@@ -29,14 +31,20 @@ DEFAULT_CREDENTIAL_FILE_NAME = "credentials.json"
 class AccQsure(object):
     def __init__(self, **kwargs):
         self._version = version("accqsure")
-        config_dir = kwargs.get("config_dir") or os.path.expanduser(
-            os.environ.get("ACCQSURE_CONFIG_DIR") or DEFAULT_CONFIG_DIR
+        config_dir = (
+            os.path.expanduser(kwargs.get("config_dir"))
+            if kwargs.get("config_dir")
+            else os.path.expanduser(
+                os.environ.get("ACCQSURE_CONFIG_DIR") or DEFAULT_CONFIG_DIR
+            )
         )
-        credentials_file = kwargs.get(
-            "credentials_file"
-        ) or os.path.expanduser(
-            os.environ.get("ACCQSURE_CREDENTIALS_FILE")
-            or f"{config_dir}/{DEFAULT_CREDENTIAL_FILE_NAME}"
+        credentials_file = (
+            os.path.expanduser(kwargs.get("credentials_file"))
+            if kwargs.get("credentials_file")
+            else os.path.expanduser(
+                os.environ.get("ACCQSURE_CREDENTIALS_FILE")
+                or f"{config_dir}/{DEFAULT_CREDENTIAL_FILE_NAME}"
+            )
         )
         self.auth = Auth(
             config_dir=config_dir,
@@ -48,6 +56,7 @@ class AccQsure(object):
         self.documents = Documents(self)
         self.manifests = Manifests(self)
         self.inspections = Inspections(self)
+        self.plots = Plots(self)
 
     @property
     def __version__(self) -> str:
@@ -98,6 +107,19 @@ class AccQsure(object):
 
         if "Content-Type" not in headers:
             headers["Content-Type"] = "application/json"
+
+        if headers["Content-Type"] == "application/json" and data is not None:
+            if isinstance(data, (dict, list, bool, type(None))):
+                # Serialize Python objects to JSON string
+                data = json.dumps(data)
+            if isinstance(data, str):
+                # Encode string to bytes
+                data = data.encode("utf-8")
+            if isinstance(data, (bytes, bytearray)):
+                # Wrap bytes in BytesIO to avoid event loop warning
+                data = io.BytesIO(data)
+            # If data is io.IOBase (e.g., BytesIO, open file), pass as-is for streaming
+
         url = f"{api_endpoint}/v1{path}"
 
         logging.debug(
@@ -112,11 +134,7 @@ class AccQsure(object):
             async with session.request(
                 method,
                 url,
-                data=(
-                    json.dumps(data)
-                    if headers["Content-Type"] == "application/json"
-                    else data
-                ),
+                data=data,
                 headers=headers,
                 params=params,
             ) as resp:
